@@ -1,15 +1,12 @@
 #!/bin/false
-# ABSTRACT: BZ::Client - A client for the Bugzilla web services API.
-
-#
-# BZ::Client.pm - Web services client for the Bugzilla server
-#
+# ABSTRACT: A client for the Bugzilla web services API.
+# PODNAME: BZ::Client
 
 use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '1.062_1';
+$BZ::Client::VERSION = '1.062_2';
 use BZ::Client::XMLRPC();
 use HTTP::Cookies();
 
@@ -195,11 +192,11 @@ __END__
 
 =head1 NAME
 
-BZ::Client - BZ::Client - A client for the Bugzilla web services API.
+BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 1.062_1
+version 1.062_2
 
 =head1 SYNOPSIS
 
@@ -208,14 +205,6 @@ version 1.062_1
                                "password" => $password);
   $client->login();
 
-=head1 NAME
-
-  BZ::Client - A client for the Bugzilla web services API.
-
-=head1 VERSION
-
-version 1.062_1
-
 =head1 CLASS METHODS
 
 This section lists the class methods of BZ::Client.
@@ -295,10 +284,20 @@ hash ref of named result objects.
 
 L<BZ::Client::Exception>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dean Hamstead <dean@bytefoundry.com.au>
 
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dean Hamstad.
