@@ -1,22 +1,20 @@
 #!/bin/false
-
-#
-# BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
-#
+# PODNAME: BZ::Client::API
+# ABSTRACT: Abstract base class for the clients of the Bugzilla API.
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::API;
-$BZ::Client::API::VERSION = '1.062_1';
+$BZ::Client::API::VERSION = '1.062_2';
 sub api_call {
     my($class, $client, $methodName, $params) = @_;
-    return $client->api_call($methodName, $params);
+    return $client->api_call($methodName, $params)
 }
 
 sub error {
     my($class, $client, $message, $http_code, $xmlrpc_code) = @_;
-    return $client->error($message, $http_code, $xmlrpc_code);
+    return $client->error($message, $http_code, $xmlrpc_code)
 }
 
 1;
@@ -25,23 +23,17 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-BZ::Client::API
+BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
 
 =head1 VERSION
 
-version 1.062_1
+version 1.062_2
 
-=head1 NAME
-
-  BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
-
-=head1 VERSION
-
-version 1.062_1
+=head1 SYNOPSIS
 
 This is an abstract base class for classes like L<BZ::Client::Product>, which
 are subclassing this one, in order to inherit common functionality.
@@ -50,10 +42,20 @@ are subclassing this one, in order to inherit common functionality.
 
   L<BZ::Client>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dean Hamstead <dean@bytefoundry.com.au>
 
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dean Hamstad.
