@@ -1,12 +1,12 @@
-#
-# BZ::Client::Bugzilla - Provides access to the Bugzilla::Webservices::Bugzilla API
-#
+#!/bin/false
+# PODNAME: BZ::Client::Bugzilla
+# ABSTRACT: Provides access to the Bugzilla::Webservices::Bugzilla API
 
 use strict;
-use warnings "all";
+use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '1.062_1';
+$BZ::Client::Bugzilla::VERSION = '1.062_2';
 use BZ::Client::API();
 
 our @ISA = qw(BZ::Client::API);
@@ -14,73 +14,65 @@ our @ISA = qw(BZ::Client::API);
 sub extensions {
     my($class, $client) = @_;
     my $params = {};
-    return $class->api_call($client, "Bugzilla.extensions", $params);
+    return $class->api_call($client, 'Bugzilla.extensions', $params);
 }
 
 sub time {
     my($class, $client) = @_;
     my $params = {};
-    $client->log("debug", "BZ::Client::Bugzilla::time: Asking");
-    my $time = $class->api_call($client, "Bugzilla.time", $params);
-    $client->log("debug", "BZ::Client::Bugzilla::time: Got $time");
-    return $time;
+    $client->log('debug', 'BZ::Client::Bugzilla::time: Asking');
+    my $time = $class->api_call($client, 'Bugzilla.time', $params);
+    $client->log('debug', 'BZ::Client::Bugzilla::time: Got $time');
+    return $time
 }
 
 sub timezone {
     my($class, $client) = @_;
     my $params = {};
-    $client->log("debug", "BZ::Client::Bugzilla::timezone: Asking");
+    $client->log('debug', 'BZ::Client::Bugzilla::timezone: Asking');
     my $timezone = $class->api_call($client, "Bugzilla.timezone", $params);
-    $client->log("debug", "BZ::Client::Bugzilla::time: Got $timezone");
-    return $timezone;
+    $client->log('debug', 'BZ::Client::Bugzilla::time: Got $timezone');
+    return $timezone
 }
 
 sub version {
     my($class, $client) = @_;
     my $params = {};
-    $client->log("debug", "BZ::Client::Bugzilla::version: Asking");
-    my $version = $class->api_call($client, "Bugzilla.version", $params);
-    $client->log("debug", "BZ::Client::Bugzilla::time: Got $version");
-    return $version;
+    $client->log('debug', 'BZ::Client::Bugzilla::version: Asking');
+    my $version = $class->api_call($client, 'Bugzilla.version', $params);
+    $client->log('debug', 'BZ::Client::Bugzilla::time: Got $version');
+    return $version
 }
 
-
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-BZ::Client::Bugzilla
+BZ::Client::Bugzilla - Provides access to the Bugzilla::Webservices::Bugzilla API
 
 =head1 VERSION
 
-version 1.062_1
+version 1.062_2
 
 =head1 SYNOPSIS
 
-  my $client = BZ::Client->new("url" => $url,
-                               "user" => $user,
-                               "password" => $password);
+This class provides methods for accessing information about the Bugzilla
+servers installation.
+
+  my $client = BZ::Client->new( url      => $url,
+                                user     => $user,
+                                password => $password);
+
   my $extensions = BZ::Client::Bugzilla->extensions($client);
   my $time = BZ::Client::Bugzilla->time($client);
   my $version = BZ::Client::Bugzilla->version($client);
 
-=head1 NAME
-
-  BZ::Client::Bugzilla - Provides information about the Bugzilla server.
-
-=head1 VERSION
-
-version 1.062_1
-
-This class provides methods for accessing information about the Bugzilla
-servers installation.
-
 =head1 CLASS METHODS
 
 This section lists the class methods, which are available in this module.
@@ -114,10 +106,20 @@ Returns the Bugzilla servers version.
 
   L<BZ::Client>, L<BZ::Client::API>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dean Hamstead <dean@bytefoundry.com.au>
 
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dean Hamstad.
