@@ -1,17 +1,14 @@
 #!/bin/false
-
-#
-#  BZ::Client::Test - Module for writing integration tests
-#
+# PODNAME: BZ::Client::Test
+# ABSTRACT: Module for writing integration tests
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::Test;
-$BZ::Client::Test::VERSION = '1.062_1';
+$BZ::Client::Test::VERSION = '1.062_2';
 use BZ::Client();
 
-
 sub new {
     my $class = shift;
     my $self;
@@ -38,7 +35,7 @@ sub new {
         $self = { @_ };
     }
     bless($self, ref($class) || $class);
-    return $self;
+    return $self
 }
 
 sub testUrl {
@@ -80,17 +77,17 @@ sub logDirectory {
 sub client {
     my $self = shift;
     if ($self->isSkippingIntegrationTests()) {
-        die "Unable to create a client, as integration tests are being skipped.";
+        die 'Unable to create a client, as integration tests are being skipped.';
     }
-    return BZ::Client->new("url" => $self->testUrl(),
-                           "user" => $self->testUser(),
-                           "password" => $self->testPassword(),
-                           "logDirectory" => $self->logDirectory());
+    return BZ::Client->new( url  => $self->testUrl(),
+                            user  => $self->testUser(),
+                            password  => $self->testPassword(),
+                            logDirectory  => $self->logDirectory())
 }
 
 sub isSkippingIntegrationTests {
     my $self = shift;
-    return !defined($self->testUrl());
+    return !defined($self->testUrl())
 }
 
 1;
@@ -99,21 +96,21 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-BZ::Client::Test
+BZ::Client::Test - Module for writing integration tests
 
 =head1 VERSION
 
-version 1.062_1
+version 1.062_2
 
 =head1 SYNOPSIS
 
   # Create a new instance, reading configuration from either of
   # the given files.
-  my $tester = BZ::Client::Test->new(["config.pl", "t/config.pl"]);
+  my $tester = BZ::Client::Test->new(['config.pl', 't/config.pl']);
   my $skipping = $tester->isSkippingIntegrationTests();
   if ($skipping) {
     # Skip integration tests
@@ -122,14 +119,6 @@ version 1.062_1
     # Run the tests, using the given client.
   }
 
-=head1 NAME
-
-  BZ::Client::Test - Module for writing integration tests
-
-=head1 VERSION
-
-version 1.062_1
-
 =head1 CLASS METHODS
 
 This section lists the class methods.
@@ -138,12 +127,12 @@ This section lists the class methods.
 
   # Create a new instance, reading configuration from either of
   # the given files.
-  my $tester = BZ::Client::Test->new(["config.pl", "t/config.pl"]);
+  my $tester = BZ::Client::Test->new(['config.pl', 't/config.pl']);
 
   # Create a new instance, providing configuration explicitly.
-  my $tester = BZ::Client->new("testUrl" => $url,
-                               "testUser" => $user,
-                               "testPassword" => $password);
+  my $tester = BZ::Client->new( 'testUrl'      => $url,
+                                'testUser'     => $user,
+                                'testPassword' => $password);
 
 Creates a new instance with a configuration for running integration
 tests. The configuration can be read from a config file or be
@@ -197,10 +186,20 @@ object, because integration tests are being skipped.
 
   L<BZ::Client>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dean Hamstead <dean@bytefoundry.com.au>
 
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dean Hamstad.
