@@ -5,7 +5,7 @@ use strict;
 use warnings "all";
 
 package BZ::Client::XMLRPC::Handler;
-$BZ::Client::XMLRPC::Handler::VERSION = '1.062_1';
+$BZ::Client::XMLRPC::Handler::VERSION = '1.062_2';
 sub new {
     my $class = shift;
     my $self = { @_ };
@@ -84,12 +84,22 @@ BZ::Client::XMLRPC::Handler
 
 =head1 VERSION
 
-version 1.062_1
+version 1.062_2
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dean Hamstead <dean@bytefoundry.com.au>
 
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dean Hamstad.
