@@ -5,7 +5,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Value;
-$BZ::Client::XMLRPC::Value::VERSION = '1.062_1';
+$BZ::Client::XMLRPC::Value::VERSION = '1.062_2';
 use BZ::Client::XMLRPC::Handler();
 use BZ::Client::XMLRPC::Struct();
 use BZ::Client::XMLRPC::Array();
@@ -137,12 +137,22 @@ BZ::Client::XMLRPC::Value
 
 =head1 VERSION
 
-version 1.062_1
+version 1.062_2
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dean Hamstead <dean@bytefoundry.com.au>
 
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Dean Hamstad.
